# dao_analyzer_components

To be able to create custom components for Dash, you need to create a node
package. This package is available at https://www.npmjs.com/package/dao-analyzer-components

## Updating dependencies

cd into this folder and run `npm update`

## Building

Use `npm run build`
